@@ -42,6 +42,7 @@
 #define HAVE_LIMITS_H 1
 #define HAVE_LINK_H 1
 #define HAVE_LINUX_UNISTD_H 1
+#define HAVE_LINUX_MMAN_H 1
 #define HAVE_LOCALE_H 1
 #define HAVE_MALLOC_H 1
 #define HAVE_MEMORY_H 1
@@ -78,7 +79,7 @@
 #define HAVE_SYS_STAT_H 1
 /* #undef HAVE_SYS_STREAM_H */
 #define HAVE_SYS_SYSCALL_H 1
-/* #undef HAVE_SYS_TIMEB_H */
+#define HAVE_SYS_TIMEB_H 1
 #define HAVE_SYS_TIMES_H 1
 #define HAVE_SYS_TIME_H 1
 #define HAVE_SYS_TYPES_H 1
@@ -102,12 +103,7 @@
 /* Libraries */
 /* #undef HAVE_LIBWRAP */
 #define HAVE_SYSTEMD 1
-/* #undef HAVE_CRC32_VPMSUM */
-
-/* Support ARMv8 crc + crypto  */
-#define HAVE_ARMV8_CRC 1
-#define HAVE_ARMV8_CRYPTO 1
-#define HAVE_ARMV8_CRC_CRYPTO_INTRINSICS 1
+#define HAVE_SYSTEMD_SD_LISTEN_FDS_WITH_NAMES 1
 
 /* Does "struct timespec" have a "sec" and "nsec" field? */
 /* #undef HAVE_TIMESPEC_TS_SEC */
@@ -174,6 +170,8 @@
 #define HAVE_DECL_MADVISE 1
 /* #undef HAVE_DECL_MHA_MAPSIZE_VA */
 #define HAVE_MALLINFO 1
+/* #undef HAVE_MALLINFO2 */
+/* #undef HAVE_MALLOC_ZONE */
 #define HAVE_MEMCPY 1
 #define HAVE_MEMMOVE 1
 #define HAVE_MKSTEMP 1
@@ -431,7 +429,7 @@
 #define PSAPI_VERSION 1     /* for GetProcessMemoryInfo() */
 
 /* We don't want the min/max macros */
-#ifdef __WIN__
+#ifdef _WIN32
 #define NOMINMAX 1
 #endif
 
@@ -530,17 +528,17 @@
 /* #undef SO_EXT */
 
 #define MYSQL_VERSION_MAJOR 10
-#define MYSQL_VERSION_MINOR 5
-#define MYSQL_VERSION_PATCH 6
+#define MYSQL_VERSION_MINOR 6
+#define MYSQL_VERSION_PATCH 4
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.5.6"
+#define PACKAGE_STRING "MySQL Server 10.6.4"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.5.6"
-#define VERSION "10.5.6"
+#define PACKAGE_VERSION "10.6.4"
+#define VERSION "10.6.4"
 #define PROTOCOL_VERSION 10
 #define PCRE2_CODE_UNIT_WIDTH 8
 
